@@ -38,7 +38,7 @@ cd ..
 echo -n "Sign $tarname? [y/N] "
 read sign
 if test "$sign" = y; then
-	gpg -ab $tarname
+	gpg -ab --default-key martin@godisch.de $tarname
 else
 	echo "No."
 fi
